import { renderless, api } from '@opentinyvue/vue-renderless/picker/vue';
import { defineComponent, directive, setup } from '@opentinyvue/vue-common';
import Input from '@opentinyvue/vue-input';
import { Clickoutside } from '@opentinyvue/vue-directive';
import DatePanel from '@opentinyvue/vue-date-panel';
import DateRange from '@opentinyvue/vue-date-range';
import MonthRange from '@opentinyvue/vue-month-range';
import YearRange from '@opentinyvue/vue-year-range';
import Time from '@opentinyvue/vue-time';
import TimeRange from '@opentinyvue/vue-time-range';
import QuarterPanel from '@opentinyvue/vue-quarter-panel';
import TimePanel from '@opentinyvue/vue-time-panel';
import Tooltip from '@opentinyvue/vue-tooltip';
import FilterBox from '@opentinyvue/vue-filter-box';
import { iconClose, iconCalendar, iconTime } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/picker/index.css';

var pickerProps = {
  type: {
    type: String,
    default: "date"
  },
  tabindex: {
    type: String,
    default: "1"
  },
  timeArrowControl: Boolean,
  timeEditable: {
    type: Boolean,
    default: true
  },
  size: String,
  format: String,
  valueFormat: String,
  timeFormat: String,
  readonly: Boolean,
  placeholder: String,
  startPlaceholder: String,
  endPlaceholder: String,
  prefixIcon: Object,
  suffixIcon: Object,
  label: String,
  shape: String,
  tip: String,
  clearIcon: {
    type: Object,
    default: function _default() {
      return iconClose();
    }
  },
  name: {
    default: "",
    validator: function validator(value) {
      return value === null || value === void 0 || typeof value === "string" || value instanceof String || Array.isArray(value) && value.length === 2 && value.every(function(item) {
        return typeof item === "string" || item instanceof String;
      });
    }
  },
  clearable: {
    type: Boolean,
    default: true
  },
  changeOnConfirm: {
    type: Boolean,
    default: false
  },
  disabled: Boolean,
  id: {
    default: "",
    validator: function validator2(value) {
      return value === null || value === void 0 || typeof value === "string" || value instanceof String || Array.isArray(value) && value.length === 2 && value.every(function(item) {
        return typeof item === "string" || item instanceof String;
      });
    }
  },
  popperClass: String,
  popperAppendToBody: {
    type: Boolean,
    default: true
  },
  align: {
    type: String,
    default: "left"
  },
  editable: {
    type: Boolean,
    default: true
  },
  modelValue: {},
  defaultValue: {},
  defaultTime: {},
  rangeSeparator: {
    type: [Object, String],
    default: "-"
  },
  unlinkPanels: Boolean,
  pickerOptions: {},
  validateEvent: {
    type: Boolean,
    default: true
  },
  isRange: Boolean,
  arrowControl: Boolean,
  timezoneData: {},
  showTimezone: {
    type: Boolean,
    default: false
  },
  defaultTimezone: String,
  isutc8: {
    type: Boolean,
    default: false
  },
  dbTimezone: Number,
  timezone: Number,
  timezoneOffset: Number,
  iso8601: Boolean,
  displayOnly: {
    type: Boolean,
    default: false
  },
  step: {
    type: Object,
    default: function _default2() {
      return {
        hour: 1,
        minute: 1,
        second: 1
      };
    }
  },
  showWeekNumber: {
    type: Boolean,
    default: false
  },
  formatWeeks: Function,
  autoFormat: {
    type: Boolean,
    default: false
  },
  title: String,
  blank: {
    type: Boolean,
    default: false
  },
  changeCompat: {
    type: Boolean,
    default: false
  },
  nowClick: {
    type: Function
  }
};

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyInput: Input,
    TinyFilterBox: FilterBox,
    TinyTooltip: Tooltip,
    IconCalendar: iconCalendar(),
    IconTime: iconTime()
  },
  emits: ["created", "select-change", "update:modelValue", "blur", "focus", "change"],
  props: pickerProps,
  directives: directive({
    Clickoutside
  }),
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      extendOptions: {
        DatePanel,
        DateRangePanel: DateRange,
        MonthRangePanel: MonthRange,
        YearRangePanel: YearRange,
        TimePanel: Time,
        TimeRangePanel: TimeRange,
        QuarterPanel,
        TimeSelect: TimePanel
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "reference",
    staticClass: "tiny-picker tiny-date-container"
  }, [_vm.shape === "filter" ? _c("tiny-filter-box", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside.mousedown",
      value: _vm.handleClose,
      expression: "handleClose",
      modifiers: {
        "mousedown": true
      }
    }],
    attrs: {
      "show-close": _vm.clearable,
      "placeholder": _vm.placeholder,
      "disabled": _vm.state.pickerDisabled,
      "label": _vm.label,
      "tip": _vm.tip,
      "value": _vm.state.displayValue.toString(),
      "drop-down-visible": _vm.state.pickerVisible,
      "blank": _vm.blank
    },
    on: {
      "click": _vm.handleFocus
    }
  }) : !_vm.state.ranged ? _c("tiny-input", _vm._b({
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside.mousedown",
      value: _vm.handleClose,
      expression: "handleClose",
      modifiers: {
        "mousedown": true
      }
    }],
    staticClass: "tiny-date-editor",
    class: "tiny-date-editor--" + _vm.state.type,
    attrs: {
      "tabindex": _vm.tabindex,
      "readonly": !_vm.editable || _vm.readonly || _vm.state.type === "dates" || _vm.state.type === "week",
      "disabled": _vm.state.pickerDisabled,
      "size": _vm.state.pickerSize,
      "name": _vm.name,
      "placeholder": _vm.placeholder,
      "model-value": _vm.state.displayValue,
      "title": _vm.state.type === "date" ? "" : _vm.state.displayValue,
      "display-only": _vm.state.isDisplayOnly,
      "display-only-content": _vm.state.displayValue,
      "validate-event": false
    },
    on: {
      "focus": _vm.handleFocus,
      "keydown": _vm.handleKeydown,
      "input": _vm.handleInput,
      "change": _vm.handleChange,
      "mouseenter": _vm.handleMouseEnter,
      "mouseleave": function mouseleave($event) {
        _vm.state.showClose = false;
      }
    },
    scopedSlots: _vm._u([_vm.label ? {
      key: "prefix",
      fn: function fn() {
        return [_c("tiny-tooltip", {
          attrs: {
            "effect": "light",
            "content": _vm.state.labelTooltip,
            "placement": "top"
          },
          nativeOn: {
            "mouseenter": function mouseenter($event) {
              return _vm.handleEnterPickerlabel.apply(null, arguments);
            }
          }
        }, [_c("span", {
          ref: "label",
          staticClass: "tiny-input__label"
        }, [_vm._v(" " + _vm._s(_vm.label) + " ")])])];
      },
      proxy: true
    } : null, {
      key: "suffix",
      fn: function fn() {
        return [_c("i", {
          staticClass: "tiny-input__icon-container"
        }, [_c("transition", {
          attrs: {
            "name": "tiny-transition-icon-scale-in"
          }
        }, [_vm.state.haveTrigger ? _c(_vm.state.showClose ? _vm.clearIcon : null, {
          tag: "component",
          staticClass: "baseClearicon",
          on: {
            "click": _vm.handleClickIcon,
            "mouseenter": function mouseenter($event) {
              _vm.state.showClose = true;
            },
            "mouseleave": function mouseleave($event) {
              _vm.state.showClose = false;
            }
          }
        }) : _vm._e()], 1), _c(_vm.state.triggerClass, {
          tag: "component",
          staticClass: "tiny-svg-size",
          on: {
            "click": _vm.handleFocus
          }
        })], 1)];
      },
      proxy: true
    }], null, true)
  }, "tiny-input", _vm.state.firstInputId, false)) : _c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside.mousedown",
      value: _vm.handleClose,
      expression: "handleClose",
      modifiers: {
        "mousedown": true
      }
    }],
    staticClass: "tiny-date-editor tiny-range-editor tiny-input tiny-input__inner",
    class: ["tiny-date-editor--" + _vm.state.type, _vm.state.pickerSize ? "tiny-range-editor--" + _vm.state.pickerSize + " tiny-input-" + _vm.state.pickerSize : "", _vm.state.pickerDisabled ? "is-disabled" : "", _vm.state.pickerVisible ? "is-active" : "", _vm.state.isDisplayOnly ? "is-display-only" : ""],
    on: {
      "click": _vm.handleFocus,
      "mouseenter": _vm.handleMouseEnter,
      "mouseleave": function mouseleave($event) {
        _vm.state.showClose = false;
      },
      "keydown": _vm.handleKeydown
    }
  }, [_c("tiny-tooltip", {
    attrs: {
      "effect": "light",
      "content": _vm.state.labelTooltip,
      "placement": "top"
    },
    nativeOn: {
      "mouseenter": function mouseenter($event) {
        return _vm.handleEnterPickerlabel.apply(null, arguments);
      }
    }
  }, [_vm.label ? _c("span", {
    ref: "label",
    staticClass: "tiny-input__label"
  }, [_vm._v(" " + _vm._s(_vm.label) + " ")]) : _vm._e()]), _c("input", _vm._b({
    staticClass: "tiny-range-input",
    attrs: {
      "autocomplete": "off",
      "placeholder": _vm.startPlaceholder,
      "disabled": _vm.state.pickerDisabled,
      "readonly": !_vm.editable || _vm.readonly,
      "name": _vm.name && _vm.name[0]
    },
    domProps: {
      "value": _vm.state.displayValue && _vm.state.displayValue[0]
    },
    on: {
      "input": _vm.handleStartInput,
      "change": _vm.handleStartChange,
      "focus": _vm.handleFocus
    }
  }, "input", _vm.state.firstInputId, false)), _vm._t("range-separator", function() {
    return [typeof _vm.rangeSeparator === "string" ? _c("span", {
      staticClass: "tiny-range-separator"
    }, [_vm._v(_vm._s(_vm.rangeSeparator))]) : _c(_vm.rangeSeparator, {
      tag: "component"
    })];
  }), _c("input", _vm._b({
    staticClass: "tiny-range-input",
    attrs: {
      "autocomplete": "off",
      "placeholder": _vm.endPlaceholder,
      "disabled": _vm.state.pickerDisabled,
      "readonly": !_vm.editable || _vm.readonly,
      "name": _vm.name && _vm.name[1]
    },
    domProps: {
      "value": _vm.state.displayValue && _vm.state.displayValue[1]
    },
    on: {
      "input": _vm.handleEndInput,
      "change": _vm.handleEndChange,
      "focus": _vm.handleFocus
    }
  }, "input", _vm.state.secondInputId, false)), _vm.state.haveTrigger ? _c("i", {
    staticClass: "tiny-input__icon tiny-range__close-icon",
    on: {
      "click": _vm.handleClickIcon
    }
  }, [_c("transition", {
    attrs: {
      "name": "tiny-transition-icon-scale-in"
    }
  }, [_c(_vm.state.showClose ? _vm.clearIcon : null, {
    tag: "component"
  })], 1)], 1) : _vm._e(), !_vm.state.isDisplayOnly ? _c("i", {
    staticClass: "tiny-input__icon tiny-range__icon tiny-input__suffix"
  }, [_c(_vm.state.triggerClass, {
    tag: "component"
  })], 1) : _vm._e(), _vm.state.isDisplayOnly ? _c("tiny-tooltip", {
    staticClass: "tiny-range-editor-display-only",
    attrs: {
      "content": _vm.state.displayOnlyTooltip,
      "effect": "light",
      "placement": "top"
    },
    nativeOn: {
      "mouseenter": function mouseenter($event) {
        return _vm.handleEnterDisplayOnlyContent.apply(null, arguments);
      }
    }
  }, [_c("span", [_vm._v(_vm._s(_vm.state.displayValue && _vm.state.displayValue.join(" " + _vm.t("ui.datepicker.to") + " ")))])]) : _vm._e()], 2), _c(_vm.state.panel, {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.pickerVisible,
      expression: "state.pickerVisible"
    }],
    ref: "picker",
    tag: "component",
    attrs: {
      "step": _vm.step,
      "show-week-number": _vm.showWeekNumber,
      "time-editable": _vm.timeEditable,
      "format-weeks": _vm.formatWeeks,
      "now-click": _vm.nowClick
    },
    on: {
      "pick": _vm.handlePick,
      "select-range": _vm.handleSelectRange,
      "select-change": _vm.handleSelectChange
    }
  }, [_vm._t("now")], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
